# FinetuneCostEstimateDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cost** | **float** |  | 

## Example

```python
from openapi_client.models.finetune_cost_estimate_dto import FinetuneCostEstimateDto

# TODO update the JSON string below
json = "{}"
# create an instance of FinetuneCostEstimateDto from a JSON string
finetune_cost_estimate_dto_instance = FinetuneCostEstimateDto.from_json(json)
# print the JSON string representation of the object
print FinetuneCostEstimateDto.to_json()

# convert the object into a dict
finetune_cost_estimate_dto_dict = finetune_cost_estimate_dto_instance.to_dict()
# create an instance of FinetuneCostEstimateDto from a dict
finetune_cost_estimate_dto_form_dict = finetune_cost_estimate_dto.from_dict(finetune_cost_estimate_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


